Index: lams_tool_scratchie/conf/language/lams/ApplicationResources_en_AU.properties
===================================================================
diff -u -rcc5ac6445941cdeeb5fd2440621630496e9f81e1 -r94be37497fa57d778f02fbb3e13436e673b12e30
--- lams_tool_scratchie/conf/language/lams/ApplicationResources_en_AU.properties (.../ApplicationResources_en_AU.properties) (revision cc5ac6445941cdeeb5fd2440621630496e9f81e1)
+++ lams_tool_scratchie/conf/language/lams/ApplicationResources_en_AU.properties (.../ApplicationResources_en_AU.properties) (revision 94be37497fa57d778f02fbb3e13436e673b12e30)
@@ -102,7 +102,6 @@
label.authoring.advanced.give.extra.point =Give an extra mark if the first scratchie attempt is the correct one.
label.authoring.scratchie.answers =Scratchie answers
label.one.or.more.questions.not.completed =One or more questions have not being completed. If you are to continue, you won't be able to answer these questions at a later stage and you'll get zero point for this questions. Are you sure you want to continue?
-label.authoring.advanced.show.results.page =After answers, show results before continuing to next activity.
label.correct.answer =Correct answer
label.mark =Mark
label.attempts =Attempts
@@ -167,7 +166,6 @@
label.learners.feedback =Learner's feedback
label.monitoring.team.leader =team leader
label.authoring.import.qti =Import IMS QTI
-label.authoring.advanced.show.results.page =Use leader selection tool results.
label.waiting.for.leader =Please, wait while somebody will become a group leader.
label.users.from.group =Other users participating in current group:
label.total =Total
@@ -177,3 +175,7 @@
label.legend =Legend
label.median =Median
label.avg.mean =Ave. Mean
+label.score =Score:
+label.you.ve.got =You''ve got {0}
+label.your.answer =Your answer:
+label.other.groups =Other groups:
Index: lams_tool_scratchie/conf/xdoclet/struts-actions.xml
===================================================================
diff -u -raab18261022d7746e10b3651bd3c864356c58a8b -r94be37497fa57d778f02fbb3e13436e673b12e30
--- lams_tool_scratchie/conf/xdoclet/struts-actions.xml (.../struts-actions.xml) (revision aab18261022d7746e10b3651bd3c864356c58a8b)
+++ lams_tool_scratchie/conf/xdoclet/struts-actions.xml (.../struts-actions.xml) (revision 94be37497fa57d778f02fbb3e13436e673b12e30)
@@ -233,7 +233,7 @@
input="/pages/learning/notebook.jsp"
parameter="submitReflection"
scope="request">
-
+
Index: lams_tool_scratchie/db/sql/create_lams_tool_scratchie.sql
===================================================================
diff -u -rd3d95be637b35c0566741de9c36ad1e8643ee14c -r94be37497fa57d778f02fbb3e13436e673b12e30
--- lams_tool_scratchie/db/sql/create_lams_tool_scratchie.sql (.../create_lams_tool_scratchie.sql) (revision d3d95be637b35c0566741de9c36ad1e8643ee14c)
+++ lams_tool_scratchie/db/sql/create_lams_tool_scratchie.sql (.../create_lams_tool_scratchie.sql) (revision 94be37497fa57d778f02fbb3e13436e673b12e30)
@@ -32,7 +32,6 @@
reflect_instructions varchar(255),
reflect_on_activity smallint,
extra_point smallint,
- show_results_page smallint,
primary key (uid)
)ENGINE=InnoDB;
create table tl_lascrt11_scratchie_item (
@@ -99,8 +98,8 @@
INSERT INTO `tl_lascrt11_scratchie` (`uid`, `create_date`, `update_date`, `create_by`, `title`, `run_offline`,
- `instructions`, `online_instructions`, `offline_instructions`, `content_in_use`, `define_later`, `content_id`, `reflect_on_activity`, `extra_point`, `show_results_page`) VALUES
- (1,NULL,NULL,NULL,'Scratchie','0','Scenario explanation ', null,null,0,0,${default_content_id},0, 0, 1);
+ `instructions`, `online_instructions`, `offline_instructions`, `content_in_use`, `define_later`, `content_id`, `reflect_on_activity`, `extra_point`) VALUES
+ (1,NULL,NULL,NULL,'Scratchie','0','Scenario explanation ', null,null,0,0,${default_content_id},0, 0);
INSERT INTO `tl_lascrt11_scratchie_item` (`uid`, `title`, `description`, `create_by`, `create_date`, `create_by_author`, `scratchie_uid`, `session_uid`, `order_id`) VALUES
(1, 'Question Title','Question Description',null,NOW(),1,1,NULL, 1);
Index: lams_tool_scratchie/src/java/org/lamsfoundation/lams/tool/scratchie/ScratchieConstants.java
===================================================================
diff -u -raab18261022d7746e10b3651bd3c864356c58a8b -r94be37497fa57d778f02fbb3e13436e673b12e30
--- lams_tool_scratchie/src/java/org/lamsfoundation/lams/tool/scratchie/ScratchieConstants.java (.../ScratchieConstants.java) (revision aab18261022d7746e10b3651bd3c864356c58a8b)
+++ lams_tool_scratchie/src/java/org/lamsfoundation/lams/tool/scratchie/ScratchieConstants.java (.../ScratchieConstants.java) (revision 94be37497fa57d778f02fbb3e13436e673b12e30)
@@ -126,10 +126,12 @@
public static final String ATTR_TITLE = "title";
public static final String ATTR_ITEM = "item";
+
+ public static final String ATTR_SCORE = "score";
+
+ public static final String ATTR_MAX_SCORE = "maxScore";
public static final String ATTR_USER_FINISHED = "userFinished";
-
- public static final String ATTR_IS_SHOW_RESULTS_PAGE = "isShowResultsPage";
public static final String ATTR_IS_GROUPED_ACTIVITY = "isGroupedActivity";
Index: lams_tool_scratchie/src/java/org/lamsfoundation/lams/tool/scratchie/dbupdates/patch20130923.sql
===================================================================
diff -u
--- lams_tool_scratchie/src/java/org/lamsfoundation/lams/tool/scratchie/dbupdates/patch20130923.sql (revision 0)
+++ lams_tool_scratchie/src/java/org/lamsfoundation/lams/tool/scratchie/dbupdates/patch20130923.sql (revision 94be37497fa57d778f02fbb3e13436e673b12e30)
@@ -0,0 +1,13 @@
+-- Turn off autocommit, so nothing is committed if there is an error
+SET AUTOCOMMIT = 0;
+
+----------------------Put all sql statements below here-------------------------
+
+-- LKC-22 Remove cloumn that is not used any longer
+ALTER TABLE tl_lascrt11_scratchie DROP COLUMN show_results_page;
+
+----------------------Put all sql statements above here-------------------------
+
+-- If there were no errors, commit and restore autocommit to on
+COMMIT;
+SET AUTOCOMMIT = 1;
Index: lams_tool_scratchie/src/java/org/lamsfoundation/lams/tool/scratchie/dto/ReflectDTO.java
===================================================================
diff -u -r6b651e7c25c7baa6a942ea7348f59701bbb4e603 -r94be37497fa57d778f02fbb3e13436e673b12e30
--- lams_tool_scratchie/src/java/org/lamsfoundation/lams/tool/scratchie/dto/ReflectDTO.java (.../ReflectDTO.java) (revision 6b651e7c25c7baa6a942ea7348f59701bbb4e603)
+++ lams_tool_scratchie/src/java/org/lamsfoundation/lams/tool/scratchie/dto/ReflectDTO.java (.../ReflectDTO.java) (revision 94be37497fa57d778f02fbb3e13436e673b12e30)
@@ -9,7 +9,7 @@
public class ReflectDTO {
private String fullName;
private boolean isGroupLeader;
-
+ private String groupName;
private String reflection;
public ReflectDTO(User user) {
@@ -32,6 +32,14 @@
this.isGroupLeader = isGroupLeader;
}
+ public String getGroupName() {
+ return groupName;
+ }
+
+ public void setGroupName(String groupName) {
+ this.groupName = groupName;
+ }
+
public String getReflection() {
return reflection;
}
Index: lams_tool_scratchie/src/java/org/lamsfoundation/lams/tool/scratchie/model/Scratchie.java
===================================================================
diff -u -r9465560dcbea622e2f3a01e334400f2005ce2ed3 -r94be37497fa57d778f02fbb3e13436e673b12e30
--- lams_tool_scratchie/src/java/org/lamsfoundation/lams/tool/scratchie/model/Scratchie.java (.../Scratchie.java) (revision 9465560dcbea622e2f3a01e334400f2005ce2ed3)
+++ lams_tool_scratchie/src/java/org/lamsfoundation/lams/tool/scratchie/model/Scratchie.java (.../Scratchie.java) (revision 94be37497fa57d778f02fbb3e13436e673b12e30)
@@ -84,8 +84,6 @@
private Set scratchieItems;
private boolean extraPoint;
-
- private boolean showResultsPage;
private boolean reflectOnActivity;
@@ -495,16 +493,4 @@
public void setExtraPoint(boolean extraPoint) {
this.extraPoint = extraPoint;
}
-
- /**
- * @hibernate.property column="show_results_page"
- * @return
- */
- public boolean isShowResultsPage() {
- return showResultsPage;
- }
-
- public void setShowResultsPage(boolean showResultsPage) {
- this.showResultsPage = showResultsPage;
- }
}
Index: lams_tool_scratchie/src/java/org/lamsfoundation/lams/tool/scratchie/service/IScratchieService.java
===================================================================
diff -u -raf388fe5ff933f084e15bfa2b72c69c9e8664518 -r94be37497fa57d778f02fbb3e13436e673b12e30
--- lams_tool_scratchie/src/java/org/lamsfoundation/lams/tool/scratchie/service/IScratchieService.java (.../IScratchieService.java) (revision af388fe5ff933f084e15bfa2b72c69c9e8664518)
+++ lams_tool_scratchie/src/java/org/lamsfoundation/lams/tool/scratchie/service/IScratchieService.java (.../IScratchieService.java) (revision 94be37497fa57d778f02fbb3e13436e673b12e30)
@@ -307,7 +307,7 @@
* @param contentId
* @return
*/
- List getReflectionList(Set users);
+ List getReflectionList(Long contentId);
/**
* Get user by UID
@@ -337,15 +337,6 @@
boolean isGroupedActivity(long toolContentID);
/**
- * Populates items with results, i.e. correctAnswer, userMark, userAttempts. Used for displaying this data on learner results page.
- *
- * @param sessionId
- * @param userUid
- * @return
- */
- Set populateItemsResults(Long sessionId, Long userUid);
-
- /**
* Return all learners in activity
*
* @param contentId
Index: lams_tool_scratchie/src/java/org/lamsfoundation/lams/tool/scratchie/service/ScratchieServiceImpl.java
===================================================================
diff -u -rbdc5af4b22897438de581bb8681d7bc7c64dbbf5 -r94be37497fa57d778f02fbb3e13436e673b12e30
--- lams_tool_scratchie/src/java/org/lamsfoundation/lams/tool/scratchie/service/ScratchieServiceImpl.java (.../ScratchieServiceImpl.java) (revision bdc5af4b22897438de581bb8681d7bc7c64dbbf5)
+++ lams_tool_scratchie/src/java/org/lamsfoundation/lams/tool/scratchie/service/ScratchieServiceImpl.java (.../ScratchieServiceImpl.java) (revision 94be37497fa57d778f02fbb3e13436e673b12e30)
@@ -789,34 +789,8 @@
return itemAttempts;
}
-
+
@Override
- public Set populateItemsResults(Long sessionId, Long userUid) {
- ScratchieSession session = scratchieSessionDao.getSessionBySessionId(sessionId);
- Scratchie scratchie = session.getScratchie();
- Set items = scratchie.getScratchieItems();
- List userLogs = scratchieAnswerVisitDao.getLogsByScratchieUser(userUid);
-
- for (ScratchieItem item : items) {
- int mark = getUserMarkPerItem(scratchie, item, userLogs);
- item.setUserMark(mark);
-
- int itemAttempts = calculateItemAttempts(userLogs, item);
- item.setUserAttempts(itemAttempts);
-
- String correctAnswer = "";
- for (ScratchieAnswer answer : (Set) item.getAnswers()) {
- if (answer.isCorrect()) {
- correctAnswer = answer.getDescription();
- }
- }
- item.setCorrectAnswer(correctAnswer);
- }
-
- return items;
- }
-
- @Override
public List getQuestionSummary(Long contentId, Long itemUid) {
List groupSummaryList = new ArrayList();
@@ -900,24 +874,29 @@
}
@Override
- public List getReflectionList(Set users) {
-
+ public List getReflectionList(Long contentId) {
ArrayList reflections = new ArrayList();
+
+ // get all available leaders associated with this content as only leaders have reflections
+ List sessionList = scratchieSessionDao.getByContentId(contentId);
+ for (ScratchieSession session : sessionList) {
+
+ ScratchieUser leader = session.getGroupLeader();
+ if (leader != null) {
+ NotebookEntry notebookEntry = getEntry(session.getSessionId(), CoreNotebookConstants.NOTEBOOK_TOOL,
+ ScratchieConstants.TOOL_SIGNATURE, leader.getUserId().intValue());
+ if ((notebookEntry != null) && StringUtils.isNotBlank(notebookEntry.getEntry())) {
+ ReflectDTO reflectDTO = new ReflectDTO(notebookEntry.getUser());
+ String reflection = StringEscapeUtils.escapeJavaScript(notebookEntry.getEntry());
+ reflectDTO.setGroupName(session.getSessionName());
+ reflectDTO.setReflection(reflection);
+ reflectDTO.setIsGroupLeader(this.isUserGroupLeader(leader, session));
- for (ScratchieUser user : users) {
- ScratchieSession session = user.getSession();
- NotebookEntry notebookEntry = getEntry(session.getSessionId(), CoreNotebookConstants.NOTEBOOK_TOOL,
- ScratchieConstants.TOOL_SIGNATURE, user.getUserId().intValue());
- if ((notebookEntry != null) && StringUtils.isNotBlank(notebookEntry.getEntry())) {
- ReflectDTO reflectDTO = new ReflectDTO(notebookEntry.getUser());
- String reflection = StringEscapeUtils.escapeJavaScript(notebookEntry.getEntry());
- reflectDTO.setReflection(reflection);
- reflectDTO.setIsGroupLeader(this.isUserGroupLeader(user, session));
-
- reflections.add(reflectDTO);
+ reflections.add(reflectDTO);
+ }
}
}
-
+
return reflections;
}
Index: lams_tool_scratchie/src/java/org/lamsfoundation/lams/tool/scratchie/web/action/MonitoringAction.java
===================================================================
diff -u -raf388fe5ff933f084e15bfa2b72c69c9e8664518 -r94be37497fa57d778f02fbb3e13436e673b12e30
--- lams_tool_scratchie/src/java/org/lamsfoundation/lams/tool/scratchie/web/action/MonitoringAction.java (.../MonitoringAction.java) (revision af388fe5ff933f084e15bfa2b72c69c9e8664518)
+++ lams_tool_scratchie/src/java/org/lamsfoundation/lams/tool/scratchie/web/action/MonitoringAction.java (.../MonitoringAction.java) (revision 94be37497fa57d778f02fbb3e13436e673b12e30)
@@ -116,7 +116,7 @@
// Create reflectList if reflection is enabled.
if (scratchie.isReflectOnActivity()) {
- List reflections = service.getReflectionList(learners);
+ List reflections = service.getReflectionList(contentId);
sessionMap.put(ScratchieConstants.ATTR_REFLECTIONS, reflections);
}
Index: lams_tool_scratchie/src/java/org/lamsfoundation/lams/tool/scratchie/web/form/ScratchieForm.java
===================================================================
diff -u -r9465560dcbea622e2f3a01e334400f2005ce2ed3 -r94be37497fa57d778f02fbb3e13436e673b12e30
--- lams_tool_scratchie/src/java/org/lamsfoundation/lams/tool/scratchie/web/form/ScratchieForm.java (.../ScratchieForm.java) (revision 9465560dcbea622e2f3a01e334400f2005ce2ed3)
+++ lams_tool_scratchie/src/java/org/lamsfoundation/lams/tool/scratchie/web/form/ScratchieForm.java (.../ScratchieForm.java) (revision 94be37497fa57d778f02fbb3e13436e673b12e30)
@@ -76,7 +76,6 @@
scratchie.setRunOffline(false);
scratchie.setReflectOnActivity(false);
scratchie.setExtraPoint(false);
- scratchie.setShowResultsPage(false);
}
}
Index: lams_tool_scratchie/web/pages/authoring/advance.jsp
===================================================================
diff -u -r9465560dcbea622e2f3a01e334400f2005ce2ed3 -r94be37497fa57d778f02fbb3e13436e673b12e30
--- lams_tool_scratchie/web/pages/authoring/advance.jsp (.../advance.jsp) (revision 9465560dcbea622e2f3a01e334400f2005ce2ed3)
+++ lams_tool_scratchie/web/pages/authoring/advance.jsp (.../advance.jsp) (revision 94be37497fa57d778f02fbb3e13436e673b12e30)
@@ -11,13 +11,6 @@
-
-
-
-
-
-
-
Index: lams_tool_scratchie/web/pages/learning/learning.jsp
===================================================================
diff -u -rc7569597546126af159f169353e68e91241b7f10 -r94be37497fa57d778f02fbb3e13436e673b12e30
--- lams_tool_scratchie/web/pages/learning/learning.jsp (.../learning.jsp) (revision c7569597546126af159f169353e68e91241b7f10)
+++ lams_tool_scratchie/web/pages/learning/learning.jsp (.../learning.jsp) (revision 94be37497fa57d778f02fbb3e13436e673b12e30)
@@ -26,7 +26,6 @@
Index: lams_tool_scratchie/web/pages/learning/notebook.jsp
===================================================================
diff -u -r8aded0b18a5a7712622ae56f38923fa297449977 -r94be37497fa57d778f02fbb3e13436e673b12e30
--- lams_tool_scratchie/web/pages/learning/notebook.jsp (.../notebook.jsp) (revision 8aded0b18a5a7712622ae56f38923fa297449977)
+++ lams_tool_scratchie/web/pages/learning/notebook.jsp (.../notebook.jsp) (revision 94be37497fa57d778f02fbb3e13436e673b12e30)
@@ -11,7 +11,7 @@
function disableFinishButton() {
document.getElementById("finishButton").disabled = true;
}
- function submitForm(methodName){
+ function submitForm(){
var f = document.getElementById('reflectionForm');
f.submit();
}
@@ -37,22 +37,12 @@
-
+
-
-
-
-
-
-
-
-
-
-
-
-
+
+
+
Index: lams_tool_scratchie/web/pages/learning/questionlist.jsp
===================================================================
diff -u -rc7569597546126af159f169353e68e91241b7f10 -r94be37497fa57d778f02fbb3e13436e673b12e30
--- lams_tool_scratchie/web/pages/learning/questionlist.jsp (.../questionlist.jsp) (revision c7569597546126af159f169353e68e91241b7f10)
+++ lams_tool_scratchie/web/pages/learning/questionlist.jsp (.../questionlist.jsp) (revision 94be37497fa57d778f02fbb3e13436e673b12e30)
@@ -1,16 +1,16 @@
<%@ include file="/common/taglibs.jsp"%>
- <%-- param has higher level for request attribute --%>
-
-
-
-
+<%-- param has higher level for request attribute --%>
+
+
+
+
-
-
-
-
-
+
+
+
+
+
${item.title}
@@ -55,7 +55,8 @@
-
+ <%-- show reflection (only for teacher) --%>
+
${sessionMap.reflectInstructions}
@@ -74,47 +75,23 @@
-
-
-
-
-
-
-
+
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
+
+
+
-
\ No newline at end of file
+
+
\ No newline at end of file
Index: lams_tool_scratchie/web/pages/learning/results.jsp
===================================================================
diff -u -rc7569597546126af159f169353e68e91241b7f10 -r94be37497fa57d778f02fbb3e13436e673b12e30
--- lams_tool_scratchie/web/pages/learning/results.jsp (.../results.jsp) (revision c7569597546126af159f169353e68e91241b7f10)
+++ lams_tool_scratchie/web/pages/learning/results.jsp (.../results.jsp) (revision 94be37497fa57d778f02fbb3e13436e673b12e30)
@@ -17,10 +17,7 @@
<%@ include file="/common/header.jsp"%>
-
+
@@ -41,44 +38,21 @@
<%@ include file="/common/messages.jsp"%>
-
- ${item.title}
+
+
+
-
-
-
-
-
-
- ${item.correctAnswer}
-
-
-
-
-
-
-
- ${item.userMark}
-
-
-
-
-
-
-
- ${item.userAttempts}
-
-
-
-
-
+
+
+ ${score}%
+
+
-
-
+
-
+
${sessionMap.reflectInstructions}
-
+
@@ -89,6 +63,9 @@
+
+
+
@@ -99,32 +76,35 @@
+
+
+
+
+
+
+
+
+ ${reflectDTO.groupName}: ${reflectDTO.reflection}
+
+
+
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
+
+
+
+
+
+
+
+
+
+
+
+
Index: lams_tool_scratchie/web/pages/monitoring/parts/advanceOptions.jsp
===================================================================
diff -u -r9465560dcbea622e2f3a01e334400f2005ce2ed3 -r94be37497fa57d778f02fbb3e13436e673b12e30
--- lams_tool_scratchie/web/pages/monitoring/parts/advanceOptions.jsp (.../advanceOptions.jsp) (revision 9465560dcbea622e2f3a01e334400f2005ce2ed3)
+++ lams_tool_scratchie/web/pages/monitoring/parts/advanceOptions.jsp (.../advanceOptions.jsp) (revision 94be37497fa57d778f02fbb3e13436e673b12e30)
@@ -31,23 +31,6 @@
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
Index: lams_tool_scratchie/web/pages/monitoring/summary.jsp
===================================================================
diff -u -rbd6de4c5f39cf4a97bd513bc58babd9401c620d9 -r94be37497fa57d778f02fbb3e13436e673b12e30
--- lams_tool_scratchie/web/pages/monitoring/summary.jsp (.../summary.jsp) (revision bd6de4c5f39cf4a97bd513bc58babd9401c620d9)
+++ lams_tool_scratchie/web/pages/monitoring/summary.jsp (.../summary.jsp) (revision 94be37497fa57d778f02fbb3e13436e673b12e30)
@@ -114,17 +114,17 @@
});
- //jqgrid autowidth (http://stackoverflow.com/a/1610197)
- $(window).bind('resize', function() {
- var grid;
- if (grid = jQuery(".ui-jqgrid-btable:visible")) {
- grid.each(function(index) {
- var gridId = $(this).attr('id');
- var gridParentWidth = jQuery('#gbox_' + gridId).parent().width();
- jQuery('#' + gridId).setGridWidth(gridParentWidth, true);
- });
- }
- });
+ //jqgrid autowidth (http://stackoverflow.com/a/1610197)
+ $(window).bind('resize', function() {
+ var grid;
+ if (grid = jQuery(".ui-jqgrid-btable:visible")) {
+ grid.each(function(index) {
+ var gridId = $(this).attr('id');
+ var gridParentWidth = jQuery('#gbox_' + gridId).parent().width();
+ jQuery('#' + gridId).setGridWidth(gridParentWidth, true);
+ });
+ }
+ });
$("#item-uid").change(function() {
var itemUid = $(this).val();
Index: lams_tool_scratchie/src/java/org/lamsfoundation/lams/tool/scratchie/web/action/LearningAction.java
===================================================================
diff -u -raab18261022d7746e10b3651bd3c864356c58a8b -r94be37497fa57d778f02fbb3e13436e673b12e30
--- lams_tool_scratchie/src/java/org/lamsfoundation/lams/tool/scratchie/web/action/LearningAction.java (.../LearningAction.java) (revision aab18261022d7746e10b3651bd3c864356c58a8b)
+++ lams_tool_scratchie/src/java/org/lamsfoundation/lams/tool/scratchie/web/action/LearningAction.java (.../LearningAction.java) (revision 94be37497fa57d778f02fbb3e13436e673b12e30)
@@ -27,9 +27,9 @@
import java.io.IOException;
import java.util.Collection;
import java.util.Date;
+import java.util.Iterator;
import java.util.List;
import java.util.Set;
-import java.util.TreeSet;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
@@ -51,14 +51,14 @@
import org.lamsfoundation.lams.notebook.service.CoreNotebookConstants;
import org.lamsfoundation.lams.tool.ToolAccessMode;
import org.lamsfoundation.lams.tool.scratchie.ScratchieConstants;
+import org.lamsfoundation.lams.tool.scratchie.dto.ReflectDTO;
import org.lamsfoundation.lams.tool.scratchie.model.Scratchie;
import org.lamsfoundation.lams.tool.scratchie.model.ScratchieAnswer;
import org.lamsfoundation.lams.tool.scratchie.model.ScratchieItem;
import org.lamsfoundation.lams.tool.scratchie.model.ScratchieSession;
import org.lamsfoundation.lams.tool.scratchie.model.ScratchieUser;
import org.lamsfoundation.lams.tool.scratchie.service.IScratchieService;
import org.lamsfoundation.lams.tool.scratchie.service.ScratchieApplicationException;
-import org.lamsfoundation.lams.tool.scratchie.util.ScratchieItemComparator;
import org.lamsfoundation.lams.tool.scratchie.web.form.ReflectionForm;
import org.lamsfoundation.lams.usermanagement.dto.UserDTO;
import org.lamsfoundation.lams.util.WebUtil;
@@ -187,7 +187,6 @@
sessionMap.put(ScratchieConstants.ATTR_IS_USER_LEADER, isUserLeader);
boolean isUserFinished = user != null && user.isSessionFinished();
sessionMap.put(ScratchieConstants.ATTR_USER_FINISHED, isUserFinished);
- sessionMap.put(ScratchieConstants.ATTR_IS_SHOW_RESULTS_PAGE, scratchie.isShowResultsPage());
sessionMap.put(AttributeNames.PARAM_TOOL_SESSION_ID, toolSessionId);
sessionMap.put(AttributeNames.ATTR_MODE, mode);
// reflection information
@@ -232,13 +231,23 @@
service.retrieveScratchesOrder(items, user);
}
+ //calculate max score
+ int maxScore = 0;
+ for (ScratchieItem item : items) {
+ maxScore += item.getAnswers().size() - 1;
+ if (scratchie.isExtraPoint()) {
+ maxScore++;
+ }
+ }
+
sessionMap.put(ScratchieConstants.ATTR_ITEM_LIST, items);
sessionMap.put(ScratchieConstants.ATTR_SCRATCHIE, scratchie);
+ sessionMap.put(ScratchieConstants.ATTR_MAX_SCORE, maxScore);
boolean isScratchingFinished = user != null && user.isScratchingFinished();
sessionMap.put(ScratchieConstants.ATTR_IS_SCRATCHING_FINISHED, isScratchingFinished);
// decide whether to show results page or learning one
- if (scratchie.isShowResultsPage() && isScratchingFinished && !mode.isTeacher()) {
+ if (isScratchingFinished && !mode.isTeacher()) {
ActionRedirect redirect = new ActionRedirect(mapping.findForwardConfig("showResults"));
redirect.addParameter(ScratchieConstants.ATTR_SESSION_MAP_ID, sessionMap.getSessionID());
redirect.addParameter(AttributeNames.ATTR_MODE, mode);
@@ -319,7 +328,8 @@
}
/**
- * Leader presses button show results. All the users set scratchingFinished to true.
+ * Displays results page.
+ * When leader gets to this page, scratchingFinished column is set to true for all users.
*
* @param mapping
* @param form
@@ -335,15 +345,41 @@
String sessionMapID = request.getParameter(ScratchieConstants.ATTR_SESSION_MAP_ID);
SessionMap sessionMap = (SessionMap) request.getSession().getAttribute(sessionMapID);
request.setAttribute(ScratchieConstants.ATTR_SESSION_MAP_ID, sessionMapID);
+
Long toolSessionId = (Long) sessionMap.get(AttributeNames.PARAM_TOOL_SESSION_ID);
-
- // only leaders should get to here to finalize scratching
- service.setScratchingFinished(toolSessionId);
-
+ ScratchieSession toolSession = service.getScratchieSessionBySessionId(toolSessionId);
ScratchieUser user = (ScratchieUser) sessionMap.get(ScratchieConstants.ATTR_USER);
- Set items = service.populateItemsResults(toolSessionId, user.getUid());
- request.setAttribute(ScratchieConstants.ATTR_ITEM_LIST, items);
+ // in case of the leader we should let all other learners see Next Activity button
+ if (service.isUserGroupLeader(user, toolSession)) {
+ service.setScratchingFinished(toolSessionId);
+ }
+
+ //get user from DB to get his updated score
+ ScratchieUser userUpdated = service.getUser(user.getUid());
+ int score = userUpdated.getMark();
+ int maxScore = (Integer) sessionMap.get(ScratchieConstants.ATTR_MAX_SCORE);
+ double percentage = (maxScore == 0) ? 0 : (score * 100/maxScore);
+ request.setAttribute(ScratchieConstants.ATTR_SCORE, (int)percentage);
+
+ // Create reflectList if reflection is enabled.
+ boolean isReflectOnActivity = (Boolean) sessionMap.get(ScratchieConstants.ATTR_REFLECTION_ON);
+ if (isReflectOnActivity) {
+ List reflections = service.getReflectionList(toolSession.getScratchie().getContentId());
+
+ //remove current session leader reflection
+ Iterator refIterator = reflections.iterator();
+ while (refIterator.hasNext()) {
+ ReflectDTO reflection = refIterator.next();
+ if (toolSession.getSessionName().equals(reflection.getGroupName())) {
+ refIterator.remove();
+ break;
+ }
+ }
+
+ request.setAttribute(ScratchieConstants.ATTR_REFLECTIONS, reflections);
+ }
+
return mapping.findForward(ScratchieConstants.SUCCESS);
}
@@ -367,11 +403,6 @@
ScratchieSession toolSession = service.getScratchieSessionBySessionId(toolSessionId);
ScratchieUser user = (ScratchieUser) sessionMap.get(AttributeNames.USER);
- // in case of the leader we should let all other learners see Next Activity button
- if (service.isUserGroupLeader(user, toolSession)) {
- service.setScratchingFinished(toolSessionId);
- }
-
String nextActivityUrl = null;
try {
nextActivityUrl = service.finishToolSession(toolSessionId, user.getUserId());
@@ -420,7 +451,7 @@
}
/**
* Submit reflection form input database.
*
* @param mapping
* @param form
@@ -433,6 +464,7 @@
initializeScratchieService();
ReflectionForm refForm = (ReflectionForm) form;
Integer userId = refForm.getUserID();
+ String entryText = refForm.getEntryText();
String sessionMapID = WebUtil.readStrParam(request, ScratchieConstants.ATTR_SESSION_MAP_ID);
SessionMap sessionMap = (SessionMap) request.getSession().getAttribute(sessionMapID);
@@ -445,15 +477,16 @@
if (entry == null) {
// create new entry
service.createNotebookEntry(sessionId, CoreNotebookConstants.NOTEBOOK_TOOL,
- ScratchieConstants.TOOL_SIGNATURE, userId, refForm.getEntryText());
+ ScratchieConstants.TOOL_SIGNATURE, userId, entryText);
} else {
// update existing entry
- entry.setEntry(refForm.getEntryText());
+ entry.setEntry(entryText);
entry.setLastModified(new Date());
service.updateEntry(entry);
}
-
- return finish(mapping, form, request, response);
+ sessionMap.put(ScratchieConstants.ATTR_REFLECTION_ENTRY, entryText);
+
+ return showResults(mapping, refForm, request, response);
}
// *************************************************************************************
@@ -420,7 +451,7 @@
}
/**
- * Submit reflection form input database.
+ * Submit reflection form input database. Only leaders can submit reflections.
*
* @param mapping